Crate kcr_dataprotection_kubeblocks_io

Crate kcr_dataprotection_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the dataprotection.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

dataprotection.kubeblocks.io/v1alpha1

  • ActionSet
  • BackupPolicy
  • BackupPolicyTemplate
  • BackupRepo
  • Backup
  • BackupSchedule
  • Restore
  • StorageProvider

Modules

v1alpha1